@@ -1,7 +1,7 @@
-#ifndef __SERVERS_SETUP_H
-#define __SERVERS_SETUP_H
+#ifndef IRSSI_CORE_SERVERS_SETUP_H
+#define IRSSI_CORE_SERVERS_SETUP_H
 
-#include "modules.h"
+#include <irssi/src/core/modules.h>
 
 #define SERVER_SETUP(server) \
 	MODULE_CHECK_CAST(server, SERVER_SETUP_REC, type, "SERVER SETUP")
@@ -11,7 +11,7 @@
 
 /* servers */
 struct _SERVER_SETUP_REC {
-#include "server-setup-rec.h"
+#include <irssi/src/core/server-setup-rec.h>
 };
 
 extern GSList *setupservers;
@@ -31,12 +31,17 @@ server_create_conn(int chat_type, const char *dest, int port,
 		   const char *chatnet, const char *password,
 		   const char *nick);
 
+SERVER_CONNECT_REC *server_create_conn_opt(int chat_type, const char *dest, int port,
+                                           const char *chatnet, const char *password,
+                                           const char *nick, GHashTable *optlist);
+
 /* Find matching server from setup. Try to find record with a same port,
    but fallback to any server with the same address. */
 SERVER_SETUP_REC *server_setup_find(const char *address, int port,
 				    const char *chatnet);
 
 void server_setup_add(SERVER_SETUP_REC *rec);
+void server_setup_modify(SERVER_SETUP_REC *rec, int old_port, const char *old_chatnet);
 void server_setup_remove(SERVER_SETUP_REC *rec);
 
 /* Remove servers attached to chatne */
